
import { useMemo } from 'react'
import ReactEcharts from 'echarts-for-react';
const LineBarCharts = () => {

  const option = useMemo(() => {
    return {
      color: ['#3CE88F', '#5F8BFF', '#F69552'],
      tooltip: {
        trigger: 'axis',
        borderWidth: '0',
        backgroundColor: 'rgba(73,81,92,.95)', //背景颜色
        textStyle: {
          color: '#fff', //字体颜色
        },
        axisPointer: {
          type: 'cross',
          crossStyle: {
            color: '#999',
          },
        },
      },
      grid: {
        left: '2%',
        right: '2%',
        bottom: '10%',
        top: '20%',
        containLabel: true,
      },
      legend: {
        data: ['立案数', '结案数', '结案率'],
      },
      xAxis: [
        {
          type: 'category',
          boundaryGap: true, //坐标轴两端不留空
          axisLine: {
            show: false, //隐藏X轴轴线
            lineStyle: {
              color: '#D9D9D9',
            },
          },
          axisLabel: {
            show: true,
            //formatter: '{value}月',
            textStyle: {
              padding: [2, 0, 0, 0],
              color: '#CBEDFF',
            },
          },
          axisTick: {
            show: false, //隐藏X轴刻度
          },
          axisPointer: {
            type: 'shadow',
          },
          data: ['09.15', '09.15', '09.15', '09.15', '09.15', '09.15', '09.15', '09.15', '09.15', '09.15', '09.15', '09.15'],
        },
      ],
      yAxis: [
        {
          type: 'value',
          name: '件',
          min: 0,
          max: 250,
          interval: 50,
          axisLabel: {
            textStyle: {
              color: '#CBEDFF',
              fontSize: 16
            },
          },
          //name的样式设计
          nameTextStyle: {
            align: 'left',
            color: '#CBEDFF',
            padding: [0, 0, 0, -30],
            fontSize: 16
          },
          splitLine: {
            show: false,
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
        },
        {
          type: 'value',
          name: '%',
          min: 0,
          max: 25,
          interval: 5,
          nameTextStyle: {
            color: '#CBEDFF',
            padding: [0, 0, 0, 30],
            fontSize: 16
          },
          axisLabel: {
            textStyle: {
              color: '#CBEDFF',
              fontSize: 16
            },
          },
          //name的样式设计
          splitLine: {
            show: false,
            // lineStyle: {
            //   type: 'solid', //设置网格线类型 dotted：虚线 solid:实线
            //   color: '#CBEDFF',
            // },
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
        },
      ],
      series: [
        {
          name: '立案数',
          type: 'bar',
          stack: true, //堆叠柱状图
          barWidth: 14, //柱状图宽度
          itemStyle: {
            // barBorderRadius: [12, 12, 12, 12],
          },
          data: [2.0, 4.9, 7.0, 23.2, 25.6, 76.7, 135.6, 162.2, 32.6, 20.0, 6.4, 3.3],
        },
        {
          name: '结案数',
          type: 'bar',
          stack: true, //堆叠柱状图
          barWidth: 14, //柱状图宽度
          itemStyle: {
            // barBorderRadius: [12, 12, 0, 0],
          },
          data: [2.6, 5.9, 9.0, 26.4, 28.7, 70.7, 175.6, 182.2, 48.7, 18.8, 6.0, 2.3],
        },
        {
          name: '结案率',
          type: 'line',
          yAxisIndex: 1,
          data: [2.0, 2.2, 3.3, 4.5, 6.3, 10.2, 20.3, 23.4, 23.0, 16.5, 12.0, 6.2],
        },
      ]
    }
  }, [])

  return (
    <ReactEcharts
      option={option} // option：图表配置项
      style={{ width: '1100px', height: '450px', margin: '0 auto' }}
    />
  )
}

export default LineBarCharts
