import { Flex, Space, useMemo } from 'antd'
import styles from './index.less'
import ListTabs from '@/pages/Common/components/ListTabs'
import IssueDescription from '@/pages/Common/components/IssueDescription'
import ProcessCard from '@/pages/Common/components/ProcessCard'
import BaseCard from '@/pages/Common/components/BaseCard'
import ListView from '@/pages/Common/components/ListView'
import EventPicList from '@/pages/Common/components/EventPicList'
import LineCharts from './LineCharts'
import Tabs from '@/components/Tabs';
import { useState } from 'react'
import { eventList } from '@/mock/event'

interface CommonListProps {
  type: string
}

const CommonList = (props: CommonListProps) => {

  const { type } = props

  // tabs内容
  const tabItems = {
    '1': [
      {
        key: '1',
        label: '处置中 1'
      },
      {
        key: '2',
        label: '待核查 1'
      },
      {
        key: '3',
        label: '待结案 0'
      },
      {
        key: '3',
        label: '已结案 0'
      }
    ],
    '2': [
      {
        key: '1',
        label: '待受理 1'
      },
      {
        key: '2',
        label: '待立案 1'
      },
      {
        key: '3',
        label: '待派遣 0'
      },
      {
        key: '3',
        label: '处置中 0'
      },
      {
        key: '4',
        label: '待核查 1'
      },
      {
        key: '5',
        label: '待结案 0'
      },
      {
        key: '6',
        label: '已结案 0'
      }
    ],
    '3': [
      {
        key: '1',
        label: '全部'
      },
      {
        key: '2',
        label: '处置中'
      },
      {
        key: '3',
        label: '已办结'
      }
    ]
  }

  // 视图
  const [viewType, setViewType] = useState<'list' | 'pic'>('pic'); //展示

  const params = {
    page: 1,
    count: 10,
    caseStatus: '',
    eventType: '',
    isDispose: '1',
  }

  //事件列表
  const [listData, setListData] = useState<any>({
    items: eventList,
    loading: true,
    total: 0,
    page: 1,
    hasNext: false,
  });

  const [fetchParams, setFetchParams] = useState<any>(params)

  const changeListTab = () => {

  }

  const onChangeCategory = () => {

  }

  const areas = [
    {
      name: '高新区',
      value: 300,
      percent: 30.6
    },
    {
      name: '新都区',
      value: 300,
      percent: 30.6
    },
    {
      name: '龙泉驿区',
      value: 300,
      percent: 30.6
    }
  ]

  const category = [
    {
      name: '类别一',
      value: 300,
      percent: 30.6
    },
    {
      name: '类别二',
      value: 300,
      percent: 30.6
    },
    {
      name: '类别三',
      value: 300,
      percent: 30.6
    }
  ]

  return (
    <Flex gap={30} className={styles.wrap}>
      <Space direction='vertical' size={15} className={styles.left}>

        <BaseCard
          style={{
            paddingTop: 15
          }}
        >
          <Flex justify='space-between' className={styles.top}>
            <Space direction='vertical' >
              <span>
                <span className={styles.num}>56</span>
                <span>件</span>
              </span>
              <span>处置中</span>
            </Space>
            <Space direction='vertical' >
              <span>
                <span className={styles.num}>56</span>
                <span>件</span>
              </span>
              <span>已办结</span>
            </Space>
            <Space direction='vertical' >
              <span>
                <span className={styles.num}>89.6</span>
                <span>%</span>
              </span>
              <span>办结率</span>
            </Space>
          </Flex>
        </BaseCard>

        <BaseCard
          title='趋势（近30天）'
          style={{
            paddingTop: 20
          }}
        >
          <div style={{ padding: '15px', width: '100%', height: '100%' }}>
            <LineCharts />
          </div>
        </BaseCard>

        <ProcessCard
          title='高发类别'
          extra={
            <Tabs
              style={{
                background: 'transparent',
                height: '30px'
              }}
              itemStyle={{
                borderRadius: '25px',
                background: 'rgba(7, 50, 93, 0.8)',
                fontSize: '16px',
                marginLeft: 8
              }}
              onChange={onChangeCategory}
              itemkey={'key'}
              items={[
                {
                  key: '1',
                  label: '大类'
                },
                {
                  key: '2',
                  label: '小类'
                },
                {
                  key: '3',
                  label: '细类'
                }
              ]}
            />
          }
          data={category}
          strokeColor={{
            '0%': '#38F2E3',
            '100%': '#3DC3FF',
          }}
        />

        <ProcessCard
          title='高发区域'
          data={areas}
          strokeColor={{
            '0%': '#FFCCCC',
            '100%': '#EEFFEB',
          }}
        />
      </Space>
      <div className={styles.right}>
        <Flex justify='flex-end' style={{ marginBottom: 20 }}>
          <Space size={20}>
            <ListTabs onChange={changeListTab} items={tabItems[type]} />
            <Space size={10}>
              <img
                src={require(`@/assets/images/event/${viewType === 'pic' ? 'picActive' : 'pic'
                  }.png`)}
                className={styles.viewTab}
                onClick={() => setViewType('pic')}
                style={{ cursor: 'pointer' }}
              />
              <img
                src={require(`@/assets/images/event/${viewType === 'list' ? 'listActive' : 'list'
                  }.png`)}
                className={styles.viewTab}
                onClick={() => setViewType('list')}
                style={{ cursor: 'pointer' }}
              />
            </Space>
          </Space>
        </Flex>
        {viewType === 'list' ? (
          <ListView
            listData={listData}
            listHeight={540}
            setParams={(data) => {
              setFetchParams({ ...fetchParams, page: data.pageNum, count: data.pageSize })
            }}
          />
        ) : (
          <EventPicList
            listData={listData}
            listHeight={640}
            setParams={(data) => {
              setFetchParams({ ...fetchParams, page: data.page })
            }}
          />
        )}
      </div>
    </Flex>
  )
}

export default CommonList;