import { useState, useEffect } from 'react'
import { Flex, Space, Select } from 'antd'
import styles from './index.less'
import ListTabs from '@/pages/Common/components/ListTabs'
import IssueDescription from '@/pages/Common/components/IssueDescription'
import ProcessCard from '@/pages/Common/components/ProcessCard'
import BaseCard from '@/pages/Common/components/BaseCard'
import ListView from '@/pages/Common/components/ListView'
import EventPicList from '@/pages/Common/components/EventPicList'
import LineCharts from './LineCharts'
import Tabs from '@/components/Tabs';
import { CaretDownOutlined } from '@ant-design/icons'
import services from '@/services'
import { eventList } from '@/mock/event'

const GeneralSituation = () => {

  const [sourceOptions, setSourceOptions] = useState([])
  const [eventStatistics, setEventStatistics] = useState<any>({})
  const [categoryStatistics, setCategoryStatistics] = useState([])
  const [areaStatistics, setAreaStatistics] = useState([])

  // 视图
  const [viewType, setViewType] = useState<'list' | 'pic'>('pic'); //展示

  const params = {
    page: 1,
    count: 10,
    caseStatus: '',
    eventType: '',
    isDispose: '1',
  }

  //事件列表
  const [listData, setListData] = useState<any>({
    items: eventList,
    loading: true,
    total: 0,
    page: 1,
    hasNext: false,
  });

  const [fetchParams, setFetchParams] = useState<any>(params)

  const changeListTab = () => {

  }

  const onChangeCategory = () => {

  }

  // 获取数据来源 筛选项
  const getSourceOptions = () => {
    const params = {
      type: '',
      time: ''
    }
    services.CityProblemApi.getComprehensiveDiscoveryStatistics(params).then(res => {
      if (res.code === 200) {
        setSourceOptions(res.data)
      }
    })
  }

  // 获取左侧顶部事件相关统计
  const getCityStatistics = () => {
    const params = {
      eventType: '',
      type: '',
      time: ''
    }
    services.CityProblemApi.getContentStatisticsApi(params).then(res => {
      if (res.code === 200) {
        setEventStatistics(res.data)
      }
    })
  }

  // 事件汇总高发类别统计
  const getCategoryAnalysis = () => {
    const params = {
      category: 'mainClass',
      type: '',
      time: ''
    }
    services.CityProblemApi.getCategoryAnalysisApi(params).then(res => {
      if (res.code === 200) {
        setCategoryStatistics(res.data)
      }
    })
  }

  // 事件汇总高发类别统计
  const getAreaAnalysis = () => {
    const params = {
      region: 'district',
      type: '',
      time: ''
    }
    services.CityProblemApi.getAreaAnalysisApi(params).then(res => {
      if (res.code === 200) {
        setAreaStatistics(res.data)
      }
    })
  }

  useEffect(() => {
    getSourceOptions()
    getCityStatistics()
    getCategoryAnalysis()
    getAreaAnalysis()
  }, [])

  return (
    <Flex gap={30} className={styles.wrap}>

      <div className={styles.searchBox}>
        <Select
          options={sourceOptions}
          style={{ width: '150px' }}
          placeholder="全部来源"
          suffixIcon={<CaretDownOutlined style={{ fontSize: 20, color: '#fff' }} />}
          fieldNames={{
            label: 'name',
            value: 'type',
          }}
        />
      </div>

      <Space direction='vertical' size={15} className={styles.left}>
        <BaseCard
          style={{
            paddingTop: 15
          }}
        >
          <Flex justify='space-between' className={styles.top}>
            <span>
              <span>总计</span>
              <span className={styles.num}>{eventStatistics.total}</span>
              <span>件</span>
            </span>
            <span>
              <span>自闭环</span>
              <span className={styles.num}>{eventStatistics.bTotal}</span>
              <span>件</span>
            </span>
            <span>
              <span>提级事件</span>
              <span className={styles.num}>{eventStatistics.promotionNum}</span>
              <span>件</span>
            </span>
          </Flex>

          <Flex
            justify='space-between'
            className={styles.top}
            style={{
              background: 'rgba(57, 122, 183, 0.2)',
              borderRadius: '20px',
              padding: '10px 15px'
            }}>
            <span>
              <span>处置中</span>
              <span className={styles.num} style={{ fontSize: '24px' }}>{eventStatistics.disposalNum}</span>
              <span>件</span>
            </span>
            <span>
              <span>已办结</span>
              <span className={styles.num} style={{ fontSize: '24px' }}>{eventStatistics.caseClosedNum}</span>
              <span>件</span>
            </span>
            <span>
              <span>办结率</span>
              <span className={styles.num} style={{ fontSize: '24px' }}>{eventStatistics.ratio}</span>
              <span>%</span>
            </span>
          </Flex>
        </BaseCard>

        <BaseCard
          title='趋势（近30天）'
          style={{
            paddingTop: 20,
          }}
        >
          <div style={{ padding: '15px', width: '100%', height: '100%' }}>
            <LineCharts data={eventStatistics.lately} />
          </div>
        </BaseCard>

        <ProcessCard
          title='高发类别'
          extra={
            <Tabs
              style={{
                background: 'transparent',
                height: '30px'
              }}
              itemStyle={{
                borderRadius: '25px',
                background: 'rgba(7, 50, 93, 0.8)',
                fontSize: '16px',
                marginLeft: 8
              }}
              onChange={onChangeCategory}
              itemkey={'key'}
              items={[
                {
                  key: '1',
                  label: '大类'
                },
                {
                  key: '2',
                  label: '小类'
                },
                {
                  key: '3',
                  label: '细类'
                }
              ]}
            />
          }
          data={categoryStatistics}
          strokeColor={{
            '0%': '#38F2E3',
            '100%': '#3DC3FF',
          }}
        />

        <ProcessCard
          title='高发区域'
          data={areaStatistics}
          strokeColor={{
            '0%': '#FFCCCC',
            '100%': '#EEFFEB',
          }}
        />
      </Space>
      <div className={styles.right}>
        <Flex justify='flex-end' style={{ marginBottom: 20 }}>
          <Space size={20}>
            <Space size={10}>
              <Select
                options={[]}
                style={{ width: '150px' }}
                placeholder="全部状态"
              />
              <Select
                options={[]}
                style={{ width: '200px' }}
                placeholder="全部事件类型"
              />
            </Space>
            <Space size={10}>
              <img
                src={require(`@/assets/images/event/${viewType === 'pic' ? 'picActive' : 'pic'
                  }.png`)}
                className={styles.viewTab}
                onClick={() => setViewType('pic')}
                style={{ cursor: 'pointer' }}
              />
              <img
                src={require(`@/assets/images/event/${viewType === 'list' ? 'listActive' : 'list'
                  }.png`)}
                className={styles.viewTab}
                onClick={() => setViewType('list')}
                style={{ cursor: 'pointer' }}
              />
            </Space>
          </Space>
        </Flex>
        {viewType === 'list' ? (
          <ListView
            listData={listData}
            listHeight={540}
            setParams={(data) => {
              setFetchParams({ ...fetchParams, page: data.pageNum, count: data.pageSize })
            }}
          />
        ) : (
          <EventPicList
            listData={listData}
            listHeight={640}
            setParams={(data) => {
              setFetchParams({ ...fetchParams, page: data.page })
            }}
          />
        )}
      </div>
    </Flex>
  )
}

export default GeneralSituation;