import DescriptionItem from '@/components/DescriptionItem';

import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import {
  CaretDownOutlined,
  CaretUpOutlined,
  DoubleRightOutlined,
} from '@ant-design/icons';
import { Col, Flex, Row, Space } from 'antd';
import React from 'react';
import { useDistrictContext } from '../..';
import LineCharts from '../LineCharts';
import styles from './index.less';
const DistrictDetailBar: React.FC = () => {
  const { selectDistrict } = useDistrictContext();
  const { dispatch } = useGlobalModalServices();
  const cards = [
    {
      name: '安全',
      value: '99.5',
      color: '#57EF58',
      background: 'rgba(39, 211, 134, 0.2)',
    },
    {
      name: '整洁',
      value: '99.5',
      color: '#FFA250',
      background: 'rgba(255, 188, 130, 0.2)',
    },
    {
      name: '有序',
      value: '99.5',
      color: '#447FF0',
      background: 'rgba(130, 173, 255, 0.2)',
    },
    {
      name: '便民',
      value: '99.5',
      color: '#57EF58',
      background: 'rgba(39, 211, 134, 0.2)',
    },
    {
      name: '美观',
      value: '99.5',
      color: '#57EF58',
      background: 'rgba(39, 211, 134, 0.2)',
    },
  ];
  const getStatus = (val: number) => {
    if (val > 95) {
      return {
        bg: 'rgb(87, 239, 88)',
        desc: '城市运行良好',
      };
    }
    if (val < 95 && val > 85) {
      return {
        bg: '#0680f4',
        desc: '城市运行基本正常',
      };
    }
    if (val < 85) {
      return {
        bg: '#ffa250',
        desc: '城市运行随时会出现问题',
      };
    }
  };
  return (
    <div className={styles.container}>
      <div className={styles.leftWrap}>
        <Flex gap={20} align="center">
          <div className={styles.title}> 实时CQI</div>
          <LineCharts></LineCharts>
          <Space size={10} align="center">
            <span className={styles.tips}>较1小时前</span>
            <div>
              <Space>
                {selectDistrict.compare > 0 ? (
                  <CaretUpOutlined style={{ color: 'rgb(9, 195, 92)' }} />
                ) : (
                  <CaretDownOutlined style={{ color: 'rgb(255, 71, 71)' }} />
                )}
                <div
                  className={styles.rightValue}
                  style={{
                    color:
                      selectDistrict.compare > 0
                        ? 'rgb(9, 195, 92)'
                        : 'rgb(255, 71, 71)',
                  }}
                >
                  {Math.abs(selectDistrict.compare)}
                </div>
              </Space>
            </div>
          </Space>
          <div className={styles.tips}>
            实时排名 <span>3</span>
          </div>
        </Flex>
        <Flex gap={10}>
          <div>
            <div
              className={styles.value}
              style={{ color: getStatus(selectDistrict.value)?.bg }}
            >
              {selectDistrict.value}
            </div>
            <div className={styles.desc}>
              {getStatus(selectDistrict.value)?.desc}
            </div>
          </div>
          {cards.map((item, index) => (
            <Flex
              vertical
              justify="center"
              align="center"
              gap={10}
              key={index}
              className={styles.card}
              style={{ background: item.background }}
            >
              <div className={styles.name}>{item.name}</div>
              <div className={styles.value} style={{ color: item.color }}>
                {item.value}
              </div>
            </Flex>
          ))}
        </Flex>
      </div>
      <div className={styles.rightWrap}>
        <Row>
          <Col span={8}>
            <div className={styles.rightTitle}>近30日最低CQI</div>
            <div
              className={styles.lowIndex}
              style={{ color: getStatus(62.2)?.bg }}
            >
              62.8
            </div>
            <div className={styles.labelStyle}>2024-10-02 周一</div>
          </Col>
          <Col span={8}>
            <div className={styles.rightTitle}>城市问题</div>
            <DescriptionItem
              value={153.2}
              name={'当前还未处置完结的案件'}
              unit={'万件'}
              labelStyle={{
                color: '#83ABC3',
                fontSize: 16,
              }}
            ></DescriptionItem>
          </Col>
          <Col span={8}>
            <div className={styles.rightTitle}>城市安全</div>
            <DescriptionItem
              value={0}
              name={'城市安全风险预警'}
              unit={'个'}
              labelStyle={{
                color: '#83ABC3',
                fontSize: 16,
              }}
            ></DescriptionItem>
          </Col>
        </Row>
      </div>

      <div
        className={styles.moreBtn}
        onClick={() => {
          console.log(selectDistrict);
          dispatch.push('districtIndex', {
            title: selectDistrict.objectName + '运行情况',
          });
        }}
      >
        查看更多
        <DoubleRightOutlined></DoubleRightOutlined>
      </div>
    </div>
  );
};

export default DistrictDetailBar;
